@@ -2,12 +2,18 @@
 # -*- coding: utf-8 -*-
 from datetime import datetime
 
-from haystack.indexes import SearchIndex, Indexable, CharField, DateTimeField
+from django.conf import settings
 
-from .models import Post, Album
+from haystack.indexes import SearchIndex, CharField, DateTimeField, Indexable
 
+from .models import Post
 
-Post.is_legacy = lambda self: False
+migration_date = getattr(settings, 'MIGRATION_DATE', None)
+if migration_date:
+    m_date = datetime.strptime(migration_date, "%Y-%m-%d").date()
+    Post.is_legacy = lambda self: m_date >= self.date_insert.date()
+else:
+    Post.is_legacy = lambda self: False
 
 
 class PostIndex(SearchIndex, Indexable):
@@ -15,30 +21,13 @@ class PostIndex(SearchIndex, Indexable):
     date_available = DateTimeField(model_attr='date_available')
     date_update = DateTimeField(model_attr='date_update')
 
-    def get_updated_field(self):
-        return 'date_update'
-
     def get_model(self):
         return Post
 
-    def index_queryset(self, using=None):
-        return self.get_model().objects.filter(
-            date_available__lte=datetime.now(),
-            published=True)
-
-
-class AlbumIndex(SearchIndex, Indexable):
-    text = CharField(document=True, use_template=True)
-    date_available = DateTimeField(model_attr='date_available')
-    date_update = DateTimeField(model_attr='date_update')
-
     def get_updated_field(self):
         return 'date_update'
 
-    def get_model(self):
-        return Album
-
     def index_queryset(self, using=None):
-        return self.get_model().objects.filter(
+        return Post.objects.filter(
             date_available__lte=datetime.now(),
             published=True)
