@@ -2,21 +2,13 @@
 # -*- coding: utf-8 -*-
 #from django.conf import settings
 #from django.utils.importlib import import_module
+import json
 from django.db import models
 from django.utils import timezone
 from django.utils.translation import ugettext_lazy as _
+from django.core.exceptions import ValidationError
 
-from opps.core.models import Publishable, BaseBox
-
-
-try:
-    OPPS_APPS = tuple([(u"{0}.{1}".format(
-        app._meta.app_label, app._meta.object_name
-    ), u"{0} - {1}".format(
-        app._meta.app_label, app._meta.object_name))
-        for app in models.get_models() if 'opps.' in app.__module__])
-except ImportError:
-    OPPS_APPS = tuple([])
+from opps.core.models import Publishable, Channeling
 
 
 class QuerySet(Publishable):
@@ -28,16 +20,39 @@ class QuerySet(Publishable):
         unique=True,
     )
 
-    model = models.CharField(_(u'Model'), max_length=150, choices=OPPS_APPS)
+    model = models.CharField(_(u'Model'), max_length=150)
     limit = models.PositiveIntegerField(_(u'Limit'), default=7)
     order = models.CharField(_('Order'), max_length=1, choices=(
         ('-', 'DESC'), ('+', 'ASC')))
     channel = models.ForeignKey(
         'channels.Channel',
         verbose_name=_(u"Channel"),
+        blank=True,
+        null=True
     )
 
+    filters = models.TextField(
+        _(u'Filters'),
+        help_text=_(u'Json format extra filters for queryset'),
+        blank=True,
+        null=True
+    )
+
+    def clean(self):
+
+        if self.filters:
+            try:
+                json.loads(self.filters)
+            except:
+                raise ValidationError(_(u'Invalid JSON'))
+
+        try:
+            self.get_queryset().all()
+        except:
+            raise ValidationError(_(u'Invalid Queryset'))
+
     def get_queryset(self):
+
         _app, _model = self.model.split('.')
         model = models.get_model(_app, _model)
 
@@ -53,23 +68,27 @@ class QuerySet(Publishable):
 
         if self.channel and not self.channel.homepage:
             queryset = queryset.filter(channel=self.channel)
+
+        if self.filters:
+            filters = json.loads(self.filters)
+            queryset = queryset.filter(**filters)
         if self.order == '-':
             queryset = queryset.order_by('-id')
 
         return queryset[:self.limit]
 
-    class Meta:
-        verbose_name = _(u'Queryset')
-        verbose_name_plural = _(u'Querysets')
 
-
-class DynamicBox(BaseBox):
-
-    dynamicqueryset = models.ForeignKey(
-        'boxes.QuerySet',
-        verbose_name=_(u'Query Set')
+class BaseBox(Publishable, Channeling):
+    name = models.CharField(_(u"Box name"), max_length=140)
+    slug = models.SlugField(
+        _(u"Slug"),
+        db_index=True,
+        max_length=150,
+        unique=True,
     )
 
     class Meta:
-        verbose_name = _(u'Dynamic Box')
-        verbose_name_plural = _(u'Dynamic Boxes')
+        abstract = True
+
+    def __unicode__(self):
+        return u"{}-{}".format(self.slug, self.site.name)
