@@ -1,13 +1,14 @@
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
-from django.core.exceptions import ValidationError, ObjectDoesNotExist
+from django.core.exceptions import ValidationError
 from django.conf import settings
 
 from mptt.models import MPTTModel, TreeForeignKey
 from mptt.managers import TreeManager
 
-from opps.core.models import Publishable, BaseConfig
+from opps.core.models import Publishable
 from opps.core.models import Slugged
 
 
@@ -26,6 +27,8 @@ class Channel(MPTTModel, Publishable, Slugged):
     name = models.CharField(_(u"Name"), max_length=60)
     long_slug = models.SlugField(_(u"Path name"), max_length=250,
                                  db_index=True)
+    layout = models.CharField(_(u'Layout'), max_length=250, db_index=True,
+                              default="default")
     description = models.CharField(_(u"Description"),
                                    max_length=255, null=True, blank=True)
     show_in_menu = models.BooleanField(_(u"Show in menu?"), default=False)
@@ -42,26 +45,26 @@ class Channel(MPTTModel, Publishable, Slugged):
     group = models.BooleanField(_(u"Group sub-channel?"), default=False)
     order = models.IntegerField(_(u"Order"), default=0)
     parent = TreeForeignKey('self', related_name='subchannel',
-                            null=True, blank=True)
+                            null=True, blank=True,
+                            verbose_name=_(u'Parent'))
 
     objects = ChannelManager()
 
     class Meta:
         unique_together = ("site", "long_slug", "slug", "parent")
-        verbose_name = _('Channel')
-        verbose_name_plural = _('Channels')
+        verbose_name = _(u'Channel')
+        verbose_name_plural = _(u'Channels')
+        ordering = ['name', 'parent__id', 'published']
 
     class MPTTMeta:
         unique_together = ("site", "long_slug", "slug", "parent")
-        order_insertion_by = ['order', 'name']
+        order_insertion_by = ['order']
 
     def __unicode__(self):
         """ Uniform resource identifier
         http://en.wikipedia.org/wiki/Uniform_resource_identifier
         """
-        if self.parent:
-            return u"/{}/{}/".format(self.parent.slug, self.slug)
-        return u"/{}/".format(self.slug)
+        return u"/{}/".format(self._set_long_slug())
 
     def get_absolute_url(self):
         return u"{}".format(self.__unicode__())
@@ -72,7 +75,7 @@ class Channel(MPTTModel, Publishable, Slugged):
     @property
     def search_category(self):
         """for use in search result"""
-        return _('Channel')
+        return _(u'Channel')
 
     @property
     def title(self):
@@ -83,45 +86,22 @@ class Channel(MPTTModel, Publishable, Slugged):
         return self.get_root()
 
     def clean(self):
+        channel_is_home = Channel.objects.filter(
+            site__id=settings.SITE_ID,
+            homepage=True, published=True)
+        if self.pk:
+            channel_is_home = channel_is_home.exclude(pk=self.pk)
 
-        try:
-            channel_exist_domain = Channel.objects.filter(
-                slug=self.slug,
-                site=self.site)
-            channel_is_home = Channel.objects.filter(
-                site__id=settings.SITE_ID,
-                homepage=True,
-                published=True)
-            if self.pk:
-                channel_is_home = channel_is_home.exclude(pk=self.pk)
-        except ObjectDoesNotExist:
-            return False
-
-        if len(channel_exist_domain) >= 1 and not self.pk:
-            raise ValidationError('Slug exist in domain!')
-
-        if self.homepage and len(channel_is_home) >= 1:
+        if self.homepage and channel_is_home.exists():
             raise ValidationError('Exist home page!')
 
-        # every class which implements Slugged needs this in clean
-        try:
-            super(Channel, self).clean()
-        except AttributeError:
-            pass  # does not implement the clean method
+        super(Channel, self).clean()
+
+    def _set_long_slug(self):
+        if self.parent:
+            return u"{}/{}".format(self.parent.long_slug, self.slug)
+        return u"{}".format(self.slug)
 
     def save(self, *args, **kwargs):
-        self.long_slug = u"{}".format(self.slug)
-        if self.parent:
-            self.long_slug = u"{}/{}".format(self.parent.slug, self.slug)
+        self.long_slug = self._set_long_slug()
         super(Channel, self).save(*args, **kwargs)
-
-
-class ChannelConfig(BaseConfig):
-    """
-    Default implementation
-    """
-    class Meta:
-        verbose_name = _(u'Channel Config')
-        verbose_name_plural = _(u'Channel Configs')
-        permissions = (("developer", "Developer"),)
-        unique_together = ("key_group", "key", "site", "channel", "article")
