@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 from datetime import datetime
 
-from haystack.indexes import SearchIndex, Indexable, CharField, DateTimeField
+from haystack.indexes import SearchIndex, CharField, DateTimeField, Indexable
 
 from .models import Channel
 
@@ -12,13 +12,13 @@ class ChannelIndex(SearchIndex, Indexable):
     date_available = DateTimeField(model_attr='date_available')
     date_update = DateTimeField(model_attr='date_update')
 
-    def get_updated_field(self):
-        return 'date_update'
-
     def get_model(self):
         return Channel
 
+    def get_updated_field(self):
+        return 'date_update'
+
     def index_queryset(self, using=None):
-        return self.get_model().objects.filter(
+        return Channel.objects.filter(
             date_available__lte=datetime.now(),
             published=True)
