@@ -8,9 +8,12 @@ from django.contrib.auth import get_user_model
 from django.utils.translation import ugettext_lazy as _
 from django.contrib.admin import SimpleListFilter
 from django.contrib.sites.models import get_current_site
+
 from opps.channels.models import Channel
 from opps.images.generate import image_url
 
+from .models import Config
+
 
 class ChannelListFilter(SimpleListFilter):
     # Human-readable title which will be displayed in the
@@ -78,17 +81,7 @@ class ChannelListFilter(SimpleListFilter):
         return queryset
 
 
-class PublishableAdmin(admin.ModelAdmin):
-    """
-    Overrides standard admin.ModelAdmin save_model method
-    It sets user (author) based on data from requet.
-    """
-    list_display = ['title', 'channel_long_slug',
-                    'date_available', 'published', 'preview_url']
-    list_filter = ['child_class', 'date_available', 'published']
-    search_fields = ['title', 'slug', 'headline', 'channel_name']
-    exclude = ('user',)
-
+class MassPublishMixin(admin.ModelAdmin):
     actions = ['publish']
 
     def publish(modeladmin, request, queryset):
@@ -97,15 +90,14 @@ class PublishableAdmin(admin.ModelAdmin):
             obj.save()
     publish.short_description = _(u'Publish/Unpublish')
 
-    def save_model(self, request, obj, form, change):
-        if not change:
-            obj.user = get_user_model().objects.get(pk=request.user.pk)
-            obj.date_insert = timezone.now()
-            obj.site = Site.objects.get(pk=settings.SITE_ID)
-        obj.date_update = timezone.now()
-        obj.save()
 
-    def in_articleboxes(self, obj):
+class PublisherAdmin(MassPublishMixin):
+    list_display = ['title', 'channel_long_slug',
+                    'date_available', 'published', 'preview_url']
+    list_filter = ['child_class', 'date_available', 'published']
+    search_fields = ['title', 'slug', 'channel_name']
+
+    def in_containerboxes(self, obj):
         articleboxes = obj.articlebox_articles.all()
         if articleboxes:
             html = [u"<ul>"]
@@ -116,13 +108,13 @@ class PublishableAdmin(admin.ModelAdmin):
             html.append(u"</ul>")
             return u"".join(html)
         return _(u"This item is not in a box")
-    in_articleboxes.allow_tags = True
-    in_articleboxes.short_description = _(u'Article boxes')
+    in_containerboxes.allow_tags = True
+    in_containerboxes.short_description = _(u'Article boxes')
 
     def image_thumb(self, obj):
         if obj.main_image:
             return u'<img width="60px" height="60px" src="{0}" />'.format(
-                image_url(obj.main_image.image.url, width=60, height=60))
+                image_url(obj.main_image.archive.url, width=60, height=60))
         return _(u'No Image')
     image_thumb.short_description = _(u'Thumbnail')
     image_thumb.allow_tags = True
@@ -145,6 +137,26 @@ class PublishableAdmin(admin.ModelAdmin):
     preview_url.allow_tags = True
 
 
+class NotUserPublishableAdmin(PublisherAdmin):
+    pass
+
+
+class PublishableAdmin(PublisherAdmin):
+    """
+    Overrides standard admin.ModelAdmin save_model method
+    It sets user (author) based on data from requet.
+    """
+    exclude = ('user',)
+
+    def save_model(self, request, obj, form, change):
+        if not change:
+            obj.user = get_user_model().objects.get(pk=request.user.pk)
+            obj.date_insert = timezone.now()
+            obj.site = Site.objects.get(pk=settings.SITE_ID)
+        obj.date_update = timezone.now()
+        obj.save()
+
+
 class BaseBoxAdmin(PublishableAdmin):
 
     prepopulated_fields = {"slug": ["name"]}
@@ -174,6 +186,15 @@ class BaseBoxAdmin(PublishableAdmin):
         return qs
 
 
+class ConfigAdmin(PublishableAdmin):
+    list_display = ['key', 'app_label', 'key_group', 'channel', 'date_insert',
+                    'date_available', 'published']
+    list_filter = ["key", 'app_label', 'key_group', "channel", "published"]
+    search_fields = ["key", "app_label", "key_group", "value"]
+
+admin.site.register(Config, ConfigAdmin)
+
+
 def apply_rules(admin_class, app):
     """
     To allow overrides of admin rules for opps apps
@@ -274,8 +295,6 @@ def apply_rules(admin_class, app):
         except:
             pass
 
-    # TODO:
-    # inlines
     inlines = rules.get('inlines')
     if inlines:
         admin_class.inlines = []
@@ -288,6 +307,7 @@ def apply_rules(admin_class, app):
             except:
                 pass
 
+    # TODO:
     # actions
     # override methods
 
