@@ -1,7 +1,8 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 from django.conf.urls import patterns, url
-from django.views.decorators.cache import cache_page
+
+from opps.core.cache import cache_page
 
 from .views import PageDetail
 
@@ -10,6 +11,6 @@ urlpatterns = patterns(
     '',
 
     # FLATPAGEs
-    url(r'^(?P<slug>[\w]+)$',
+    url(r'^page/(?P<slug>[\w]+)/$',
         cache_page(60 * 2)(PageDetail.as_view()), name='open'),
 )
