@@ -26,11 +26,17 @@ def _prepend_media_url(url):
 
 
 def image_url(image_url, **kwargs):
+    if not settings.THUMBOR_ENABLED or image_url.split('.')[-1] == 'gif':
+        # TODO: alternative ways for generating the thumbnails
+        return image_url
+
     image_url = _prepend_media_url(image_url)
     image_url = _remove_schema(image_url)
 
-    encrypted_url = crypto.generate(image_url=image_url,
-                                    **dict(settings.THUMBOR_ARGUMENTS,
-                                           **kwargs)).strip('/')
-
-    return u'{}/{}'.format(settings.THUMBOR_SERVER, encrypted_url)
+    try:
+        encrypted_url = crypto.generate(
+            image_url=image_url,
+            **dict(settings.THUMBOR_ARGUMENTS, **kwargs)).strip('/')
+        return u'{}/{}'.format(settings.THUMBOR_SERVER, encrypted_url)
+    except:
+        return u""
