@@ -1,18 +1,19 @@
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 from django.contrib.sitemaps import GenericSitemap as DjangoGenericSitemap
 from django.contrib.sitemaps import Sitemap as DjangoSitemap
 from django.utils import timezone
 
-from opps.articles.models import Article
+from opps.containers.models import Container
 
 
 def InfoDisct(googlenews=False):
-    article = Article.objects.filter(date_available__lte=timezone.now(),
-                                     published=True)
+    containers = Container.objects.filter(date_available__lte=timezone.now(),
+                                          published=True)
     if googlenews:
-        article = article[:1000]
+        containers = containers[:1000]
     return {
-        'queryset': article,
+        'queryset': containers,
         'date_field': 'date_available',
     }
 
@@ -21,8 +22,8 @@ class BaseSitemap(DjangoSitemap):
     priority = 0.6
 
     def items(self):
-        return Article.objects.filter(date_available__lte=timezone.now(),
-                                      published=True)
+        return Container.objects.filter(date_available__lte=timezone.now(),
+                                        published=True)
 
     def lastmod(self, obj):
         return obj.date_available
